==> client-3.6.0-sources.jar: com/nexmo/client/verify/CheckEndpoint.java <==
/*
 * Copyright (c) 2011-2017 Nexmo Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.nexmo.client.verify;

import com.nexmo.client.HttpWrapper;
import com.nexmo.client.NexmoClientException;

import java.io.IOException;

class CheckEndpoint {
    private CheckMethod checkMethod;

    CheckEndpoint(HttpWrapper httpWrapper) {
        this.checkMethod = new CheckMethod(httpWrapper);
    }

    CheckResult check(final String requestId,
                      final String code,
                      final String ipAddress) throws IOException, NexmoClientException {
        return check(new CheckRequest(requestId, code, ipAddress));
    }

    CheckResult check(final String requestId, final String code) throws IOException, NexmoClientException {
        return check(new CheckRequest(requestId, code));
    }

    private CheckResult check(CheckRequest request) throws IOException, NexmoClientException {
        // TODO: Remove translation when releasing 4.0
        return translateFromCheckResponse(this.checkMethod.execute(request));
    }

    private CheckResult translateFromCheckResponse(CheckResponse response) {
        return new CheckResult(
                // TODO: In 4.0 this will be permitted to be null.
                response.getStatus() != null ? response.getStatus().getVerifyStatus() : Integer.MAX_VALUE,
                response.getRequestId(),
                response.getEventId(),
                response.getPrice() != null ? response.getPrice().floatValue() : 0,
                response.getCurrency(),
                response.getErrorText(),
                response.getStatus() != null && response.getStatus().isTemporaryError());
    }
}

==> client-5.1.0-sources.jar: com/nexmo/client/verify/CheckEndpoint.java <==
/*
 * Copyright (c) 2011-2017 Nexmo Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.nexmo.client.verify;

import com.nexmo.client.HttpWrapper;
import com.nexmo.client.NexmoClientException;

import java.io.IOException;

class CheckEndpoint {
    private CheckMethod checkMethod;

    CheckEndpoint(HttpWrapper httpWrapper) {
        this.checkMethod = new CheckMethod(httpWrapper);
    }

    CheckResponse check(final String requestId, final String code, final String ipAddress) throws IOException, NexmoClientException {
        return check(new CheckRequest(requestId, code, ipAddress));
    }

    CheckResponse check(final String requestId, final String code) throws IOException, NexmoClientException {
        return check(new CheckRequest(requestId, code));
    }

    private CheckResponse check(CheckRequest request) throws IOException, NexmoClientException {
        return this.checkMethod.execute(request);
    }
}
